@@ -16,7 +16,7 @@
 # package info
 #-------------------------------------------------------------------------------
 #
-__version__ = '1.1.1'
+__version__ = '1.1.2'
 
 #-------------------------------------------------------------------------------
 # default values
@@ -126,7 +126,7 @@ def get_param(name):
 #-------------------------------------------------------------------------------
 #
 def fmt(time):
-	return "%0.3f ms" % time if time is not None else "None"
+	return "%0.3f s" % time if time is not None else "None"
 # end function
 
 #-------------------------------------------------------------------------------
